@@ -1,4 +1,4 @@
-#ident "$Id: syslinux.c,v 1.6 1998/02/14 00:26:21 hpa Exp $"
+#ident "$Id: syslinux.c,v 1.7 1998/02/20 22:35:47 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 1998 H. Peter Anvin - All Rights Reserved
@@ -287,9 +287,10 @@ int main(int argc, char *argv[])
     } else if ( f == 0 ) {
       if ( S_ISREG(st.st_mode) )
 	execl(_PATH_MOUNT, _PATH_MOUNT, "-t", "msdos", "-o", "loop", "-w",
-	      device, mntpath);
+	      device, mntpath, NULL);
       else
-	execl(_PATH_MOUNT, _PATH_MOUNT, "-t", "msdos", "-w", device, mntpath);
+	execl(_PATH_MOUNT, _PATH_MOUNT, "-t", "msdos", "-w", device, mntpath,
+	      NULL);
       _exit(255);		/* execl failed */
     }
   }
